/**
 * Copyright 2011 Bill Brown
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.colorfulsoftware.rss;

import java.io.Serializable;

/**
 * <p>
 * The &lt;generator> element.
 * </p>
 * <p>
 * From the <a href="http://cyber.law.harvard.edu/rss/rss.html">RSS 2.0
 * specification</a>...
 * </p>
 * <p>
 * A string indicating the program used to generate the channel.
 * </p>
 * 
 * @author Bill Brown
 * 
 */
public class Generator implements Serializable {

	private static final long serialVersionUID = -4131939434912584770L;

	private final String generator;

	Generator(String generator) throws RSSpectException {
		if (generator == null || generator.equals("")) {
			throw new RSSpectException("generator SHOULD NOT be blank.");
		}
		this.generator = generator;
	}

	Generator(Generator generator) {
		this.generator = generator.generator;
	}

	/**
	 * @return the generator of the feed.
	 */
	public String getGenerator() {
		return generator;
	}

	/**
	 * Shows the contents of the &lt;generator> element.
	 */
	@Override
	public String toString() {
		return "<generator>" + generator + "</generator>";
	}
	
	@Override
	public boolean equals(Object obj) {
		if (obj == this) {
			return true;
		}
		if (!(obj instanceof Generator)) {
			return false;
		}
		return this.toString().equals(obj.toString());
	}
	
	@Override public int hashCode() {
		return toString().hashCode();
	}

}
